%%  Classe de These pour l'ENIS construite au-dessus de thloria.

%%  Auteur: Bechir ZALILA (bechir.zalila@redcad.org)
%%  $Id: thenis.cls 15411 2022-01-07 10:35:00Z zalila $

\NeedsTeXFormat{LaTeX2e}[1997/12/01]
\ProvidesClass{thenis}[2021/11/15 (B. ZALILA, ENIS))]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{thloria}}
\ProcessOptions
\LoadClass[openright]{thloria}

\RequirePackage[usenames,dvipsnames]{xcolor}

%%  Personnalisation de la page de titre
\SetTLFont{ThesisFirstPageHead}%
          {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{10}{14}%
\SetTLFont{ThesisTitle}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{20}{30}%
\SetTLFont{ThesisKind}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{30}{30}%
\SetTLFont{ThesisPresentedThe}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{m}{n}{10.95}{13}%
\SetTLFont{ThesisInOrderToGet}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{m}{n}{10.95}{13}%
\SetTLFont{ThesisDiploma}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{14}{18}%
\SetTLFont{ThesisSpecialty}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{10.95}{13}%
\SetTLFont{ThesisPresentedBy}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{m}{n}{10.95}{13}%
\SetTLFont{ThesisAuthor}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{m}{n}{14}{18}%
\SetTLFont{ThesisJuryTitle}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{10.95}{13}%
\SetTLFont{ThesisJury}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{m}{n}{10.95}{13}%
\SetTLFont{ThesisFirstPageFoot}%
             {\TitlePageFontEncoding}{\TitlePageFontFamily}{bx}{n}{10}{14}%

\newcommand{\@ThesisNOrdre}%
        {{\UseEntryFont{ThesisAuthor}%
            \fbox{\'ecrire \tt\char`\\ThesisNOrdre\{ N°D'ordre \}}}}
\newcommand\ThesisNOrdre[1]%
        {\renewcommand{\@ThesisNOrdre}{{\UseEntryFont{ThesisAuthor}#1}}}
             
\renewcommand{\@ThesisKind}{{\UseEntryFont{ThesisKind}Habilitation Universitaire}}

\renewcommand\@thesis@titlep@gebody{%
  %---------------------------------------------------
  \@ThesisFirstPageHead
  \vskip20mm plus2fil
  \begin{center}
    \textcolor{violet}{\rule{16cm}{1mm}}
    \vskip10mm
    \@ThesisKind
    \vskip5mm plus2fil
    \@ThesisPresentedThe
    \vskip3mm plus1fil
    \@ThesisInOrderToGet
    \vskip5mm plus1fil
    \@ThesisDiploma
    \vskip3mm plus1fil
    \@ThesisPresentedBy
    \vskip3mm plus1fil
    \@ThesisAuthor
    \vskip10mm
    \textcolor{darkgray}{\rule{6cm}{1mm}}
    \vskip3mm
    \@ThesisTitle
    \vskip3mm
    \textcolor{darkgray}{\rule{6cm}{1mm}}
  \end{center}
  \vskip5mm plus2fil
  \hskip1cm\@ThesisJuryTitle
  \begin{center}
    \@ThesisJury
  \end{center}
  \vskip5mm
  \@ThesisFirstPageFoot
  %---------------------------------------------------
}%

\renewenvironment{ThesisAbstract}
    {\ifabstracts@even\@newevendoublepage\else\@newdoublepage\fi
     \edef\saved@ps{\current@ps}%
     \pagestyle{\abs@ps}
     \markboth{}{}
     \def\@abstr@ct@beginning##1##2{%
         \section*{\@title@lignment ##1}
         \@abstract@hook{##1}%
         \if@tocswitch
            \DontFrameThisInToc
            \if@classic@section
               \addcontentsline{toc}{tlstarchapter}{##1}
            \else
               \addcontentsline{toc}{spsection}{##1}
            \fi
         \fi
         \reset@numbertocswitch
         \reset@frame@switch
         \def\KeyWords####1{\par\bigskip\noindent\textbf{##2:} ####1\par}
         }
     \newenvironment{FrenchAbstract}
        {\@abstr@ct@beginning{R\'esum\'e}{Mots-cl\'es}}
        {\vglue1cm minus 8mm}
     \newenvironment{EnglishAbstract}
        {\@abstr@ct@beginning{Abstract}{Keywords}%
         \ifx\english\@undefined
             \bgroup\language=0\relax
         \else
             \begin{english}
         \fi
         \leavevmode\hbox to\parindent{}\ignorespaces % 22/7/1994
        }
        {\ifx\english\@undefined
             \egroup
         \else
             \end{english}
         \fi
         \vglue1cm minus 8mm
        }
     \@mkboth{}{}%
     \vglue.5cm
    }
    {\global\@tocswitchfalse
     \global\@classic@sectionfalse
     %\@newdoublepage
     \long\def\@empty@ps{empty}%
     \newpage
     \if@twoside
       \ifodd\c@page
       \else
          \hbox{}%
          \ifx\@empty@ps\abs@ps
          \else
             \@empty@ps@cmd
          \fi
          \newpage
          \if@twocolumn\hbox{}\newpage\fi
          \pagestyle{\saved@ps}%
       \fi
     \else
       \pagestyle{\saved@ps}%
     \fi
     %\addtocounter{page}{-2}%
    }

%%  Suppression de la phrase ``Mis en page avec la classe thloria'' de
%%  la page 2.
\nthks

%% En tête de la thèse ENIS
\newcommand{\@ENIShe@d}{{\UseEntryFont{ThesisFirstPageHead}\noindent
    \centerline{\if@logos@enis@
      {\setbox0=\hbox{$\raise2.5cm\hbox{\ENISLogos}$}%
        \ht0=\baselineskip\box0}\hfill
      \else
      \'Ecole Nationale Sup\'erieure des T\'el\'ecommunications%
      \fi}%
}}

%% Logo de l'ENIS
\newcommand\ENISLogos{%
  \vtop to0pt{\hbox{}\hbox to0pt{
      \parbox[t][3cm]{0.5\linewidth}{\centering R\'epublique Tunisienne\\
        Minist\`ere de l'Enseignement Sup\'erieur et de\\
        la Recherche Scientifique\\
        \rule{2cm}{1mm}\\
        Université de Sfax\\
      \'Ecole Nationale d'Ing\'enieurs de Sfax}
      \parbox[t][3cm]{0.2\linewidth}{\vskip 0.5cm \includegraphics[width=2cm]{enis}}
      \parbox[t][3cm]{0.5\linewidth}{\centering Cycle de formation doctorale dans\\
        la discipline Ing\'enierie des\\
        Syst\`emes Informatiques\\
        \@ThesisAuthor\\
        Habilitation Universitaire\\
      N° d'ordre: \@ThesisNOrdre}\hss}\vss} }

\newif\if@logos@enis@
\newcommand\ShowLogosENIS{\@logos@true\@logos@enis@true}
\@onlypreamble\ShowLogosENIS
\ShowLogosENIS

%%  Nouveau type de thèse
\newcommand\ThesisENIS{\renewcommand{\@ThesisFirstPageHead}{\@ENIShe@d}%
  \renewcommand{\@ThesisFirstPageFoot}{}% TODO
  \ThesisDiploma{{\UseEntryFont{ThesisDiploma}%
      Doctorat de l'\'Ecole Nationale d'\'Ing\'enieurs de Sfax\\[3mm]
      {\UseEntryFont{ThesisSpecialty}sp\'ecialit\'e~:
        {\bf Ing\'enierie des Syst\`emes Informatiques}}}}}

%%  Nouveau type d'habilitation
\newcommand\HUENIS{\renewcommand{\@ThesisFirstPageHead}{\@ENIShe@d}%
  \renewcommand{\@ThesisFirstPageFoot}{}% TODO
  \ThesisInOrderToGet{pour l'obtention de l'}
  \ThesisDiploma{{\UseEntryFont{ThesisDiploma}%
      Habilitation Universitaire\\[3mm]
      {\UseEntryFont{ThesisSpecialty}dans la discipline~:
        {\bf Ing\'enierie des Syst\`emes Informatiques}}}}}

%%  Nouvelle catégorie de Jury
\NewJuryCategory{Directeurs}{\it Directeur de th\`ese :}
                            {\it Directeurs de th\`ese :}

%%  Entêtes et pieds de pages personnalisés
\newcommand\ps@ENISHeadingsI{%
  \ifx\thesiscopyrightholder\undefined\def\thesiscopyrightholder{TELECOM~ParisTech}\fi
  \ifx\thesiscopyrightyear\undefined\def\thesiscopyrightyear{2008}\fi
  \def\thesiscopyrightnotice{{\tiny\textcopyright~\thesiscopyrightyear~\thesiscopyrightholder}}
  \def\@oddfoot{\thesiscopyrightnotice\hfil\thepage}%
  \def\@evenfoot{\thepage\hfil\thesiscopyrightnotice}%
  \def\@evenhead{\@gener@lhe@d{\leftmark}%
    {{\slshape\leftmark}\hfil}}%
  \def\@oddhead{\@gener@lhe@d{\leftmark\rightmark}%
    {\hfil\slshape\rightmark}}%
  \let\@mkboth\markboth
  \let\chaptermark\@chaptermark
  \let\sectionmark\@sectionmark
}

%% END
\endinput

%%% Local Variables:
%%% mode: latex
%%% mode: flyspell
%%% ispell-dictionary: "fr"
%%% End:
